@@ -1,5 +1,5 @@
 package HackaMol::Roles::MolReadRole;
-$HackaMol::Roles::MolReadRole::VERSION = '0.049';
+$HackaMol::Roles::MolReadRole::VERSION = '0.050';
 # ABSTRACT: Read files with molecular information
 use Moose::Role;
 use Carp;
@@ -77,7 +77,7 @@ sub read_file_cif_parts {
     my $fh   = FileHandle->new("<$file") or croak "unable to open $file";
     my $info = $self->read_cif_info($fh);
     my @models = $self->read_cif_atoms($fh);
-    $info = $self->read_cif_info($fh,$info);
+    #$info = $self->read_cif_info($fh,$info);
     my @mols = map {
         HackaMol::Molecule->new(
           name => "model." . $_->[0]->model_num,
@@ -134,7 +134,7 @@ HackaMol::Roles::MolReadRole - Read files with molecular information
 
 =head1 VERSION
 
-version 0.049
+version 0.050
 
 =head1 SYNOPSIS
 
